Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS WAF V2.

Actions, resources, and condition keys for AWS WAF V2 - Service Authorization Reference

# Actions, resources, and condition keys for AWS WAF V2

AWS WAF V2 (service prefix: `wafv2` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS WAF V2
- Resource types defined by AWS WAF V2
- Condition keys for AWS WAF V2

## Actions defined by AWS WAF V2

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateWebACL | Grants permission to associate a WebACL with a resource | Write | webacl* |  |
apigateway |  |
appsync |  |
loadbalancer/app/ |  |
CheckCapacity | Grants permission to calculate web ACL capacity unit (WCU) requirements for a specified scope and set of rules | Read |  |  |
CreateIPSet | Grants permission to create an IPSet | Write | ipset* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateRegexPatternSet | Grants permission to create a RegexPatternSet | Write | regexpatternset* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateRuleGroup | Grants permission to create a RuleGroup | Write | rulegroup* |  |
ipset |  |
regexpatternset |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateWebACL | Grants permission to create a WebACL | Write | webacl* |  |
ipset |  |
managedruleset |  |
regexpatternset |  |
rulegroup |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteFirewallManagerRuleGroups | Grants permission to delete FirewallManagedRulesGroups from a WebACL if not managed by Firewall Manager anymore | Write | webacl* |  |
DeleteIPSet | Grants permission to delete an IPSet | Write | ipset* |  |
DeleteLoggingConfiguration | Grants permission to delete the LoggingConfiguration from a WebACL | Write | webacl* |  |
DeletePermissionPolicy | Grants permission to delete the PermissionPolicy on a RuleGroup | Permissions management | rulegroup* |  |
DeleteRegexPatternSet | Grants permission to delete a RegexPatternSet | Write | regexpatternset* |  |
DeleteRuleGroup | Grants permission to delete a RuleGroup | Write | rulegroup* |  |
DeleteWebACL | Grants permission to delete a WebACL | Write | webacl* |  |
DescribeManagedRuleGroup | Grants permission to retrieve high-level information for a managed rule group | Read |  |  |
DisassociateFirewallManager [permission only] | Grants permission to disassociate Firewall Manager from a WebACL | Write | webacl* |  |
DisassociateWebACL | Grants permission to disassociate a WebACL from an application resource | Write | apigateway |  |
appsync |  |
loadbalancer/app/ |  |
GenerateMobileSdkReleaseUrl | Grants permission to generate a presigned download URL for the specified release of the mobile SDK | Read |  |  |
GetIPSet | Grants permission to retrieve details about an IPSet | Read | ipset* |  |
| aws:ResourceTag/${TagKey} |
GetLoggingConfiguration | Grants permission to retrieve LoggingConfiguration for a WebACL | Read | webacl* |  |
| aws:ResourceTag/${TagKey} |
GetManagedRuleSet | Grants permission to retrieve details about a ManagedRuleSet | Read | managedruleset* |  |
GetMobileSdkRelease | Grants permission to retrieve information for the specified mobile SDK release, including release notes and tags | Read |  |  |
GetPermissionPolicy | Grants permission to retrieve a PermissionPolicy for a RuleGroup | Read | rulegroup* |  |
GetRateBasedStatementManagedKeys | Grants permission to retrieve the keys that are currently blocked by a rate-based rule | Read | webacl* |  |
| aws:ResourceTag/${TagKey} |
GetRegexPatternSet | Grants permission to retrieve details about a RegexPatternSet | Read | regexpatternset* |  |
| aws:ResourceTag/${TagKey} |
GetRuleGroup | Grants permission to retrieve details about a RuleGroup | Read | rulegroup* |  |
| aws:ResourceTag/${TagKey} |
GetSampledRequests | Grants permission to retrieve detailed information about a sampling of web requests | Read | webacl* |  |
GetWebACL | Grants permission to retrieve details about a WebACL | Read | webacl* |  |
| aws:ResourceTag/${TagKey} |
GetWebACLForResource | Grants permission to retrieve the WebACL that's associated with a resource | Read | apigateway |  |
appsync |  |
loadbalancer/app/ |  |
ListAvailableManagedRuleGroupVersions | Grants permission to retrieve an array of managed rule group versions that are available for you to use | List |  |  |
ListAvailableManagedRuleGroups | Grants permission to retrieve an array of managed rule groups that are available for you to use | List |  |  |
ListIPSets | Grants permission to retrieve an array of IPSetSummary objects for the IP sets that you manage | List |  |  |
ListLoggingConfigurations | Grants permission to retrieve an array of your LoggingConfiguration objects | List |  |  |
ListManagedRuleSets | Grants permission to retrieve an array of your ManagedRuleSet objects | List |  |  |
ListMobileSdkReleases | Grants permission to retrieve a list of the available releases for the mobile SDK and the specified device platform | List |  |  |
ListRegexPatternSets | Grants permission to retrieve an array of RegexPatternSetSummary objects for the regex pattern sets that you manage | List |  |  |
ListResourcesForWebACL | Grants permission to retrieve an array of the Amazon Resource Names (ARNs) for the resources that are associated with a web ACL | List | webacl* |  |
ListRuleGroups | Grants permission to retrieve an array of RuleGroupSummary objects for the rule groups that you manage | List |  |  |
ListTagsForResource | Grants permission to list tags for a resource | Read | ipset |  |
regexpatternset |  |
rulegroup |  |
webacl |  |
| aws:ResourceTag/${TagKey} |
ListWebACLs | Grants permission to retrieve an array of WebACLSummary objects for the web ACLs that you manage | List |  |  |
PutFirewallManagerRuleGroups [permission only] | Grants permission to create FirewallManagedRulesGroups in a WebACL | Write | webacl* |  |
PutLoggingConfiguration | Grants permission to enable a LoggingConfiguration, to start logging for a web ACL | Write | webacl* |  | iam:CreateServiceLinkedRole
PutManagedRuleSetVersions | Grants permission to enable create a new or update an existing version of a ManagedRuleSet | Write | managedruleset* |  |
rulegroup* |  |
PutPermissionPolicy | Grants permission to attach an IAM policy to a resource, used to share rule groups between accounts | Permissions management | rulegroup* |  |
TagResource | Grants permission to associate tags with a AWS resource | Tagging | ipset |  |
regexpatternset |  |
rulegroup |  |
webacl |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to disassociate tags from an AWS resource | Tagging | ipset |  |
regexpatternset |  |
rulegroup |  |
webacl |  |
| aws:TagKeys |
UpdateIPSet | Grants permission to update an IPSet | Write | ipset* |  |
| aws:ResourceTag/${TagKey} |
UpdateManagedRuleSetVersionExpiryDate | Grants permission to update the expiry date of a version in ManagedRuleSet | Write | managedruleset* |  |
UpdateRegexPatternSet | Grants permission to update a RegexPatternSet | Write | regexpatternset* |  |
| aws:ResourceTag/${TagKey} |
UpdateRuleGroup | Grants permission to update a RuleGroup | Write | rulegroup* |  |
ipset |  |
regexpatternset |  |
| aws:ResourceTag/${TagKey} |
UpdateWebACL | Grants permission to update a WebACL | Write | webacl* |  |
ipset |  |
managedruleset |  |
regexpatternset |  |
rulegroup |  |
| aws:ResourceTag/${TagKey} |

## Resource types defined by AWS WAF V2

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
webacl | `arn:$ { Partition}:wafv2:$ { Region}:$ { Account}:$ { Scope}/webacl/$ { Name}/$ { Id}` | aws:ResourceTag/${TagKey}
ipset | `arn:$ { Partition}:wafv2:$ { Region}:$ { Account}:$ { Scope}/ipset/$ { Name}/$ { Id}` | aws:ResourceTag/${TagKey}
managedruleset | `arn:$ { Partition}:wafv2:$ { Region}:$ { Account}:$ { Scope}/managedruleset/$ { Name}/$ { Id}` |
rulegroup | `arn:$ { Partition}:wafv2:$ { Region}:$ { Account}:$ { Scope}/rulegroup/$ { Name}/$ { Id}` | aws:ResourceTag/${TagKey}
regexpatternset | `arn:$ { Partition}:wafv2:$ { Region}:$ { Account}:$ { Scope}/regexpatternset/$ { Name}/$ { Id}` | aws:ResourceTag/${TagKey}
loadbalancer/app/ | `arn:$ { Partition}:elasticloadbalancing:$ { Region}:$ { Account}:loadbalancer/app/$ { LoadBalancerName}/$ { LoadBalancerId}` |
apigateway | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { ApiId}/stages/$ { StageName}` |
appsync | `arn:$ { Partition}:appsync:$ { Region}:$ { Account}:apis/$ { GraphQLAPIId}` |

## Condition keys for AWS WAF V2

AWS WAF V2 defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filters access by tag-value associated with the resource | String
aws:TagKeys | Filters access by the presence of mandatory tags in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.